pub struct DeleteBigWordEnd(pub usize);Expand description
Deletes from the cursor to the end of the current WORD, without consuming
trailing whitespace. This is the cW primitive, which in Vim behaves like
cE rather than dW. A WORD is any sequence of non-whitespace characters.
Tuple Fields
0: usizeTrait Implementations
Sourceimpl Clone for DeleteBigWordEnd
impl Clone for DeleteBigWordEnd
Sourcefn clone(&self) -> DeleteBigWordEnd
fn clone(&self) -> DeleteBigWordEnd
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for DeleteBigWordEnd
Sourceimpl Debug for DeleteBigWordEnd
impl Debug for DeleteBigWordEnd
Sourceimpl Execute for DeleteBigWordEnd
impl Execute for DeleteBigWordEnd
fn execute(&mut self, state: &mut EditorState)
Sourcefn is_repeatable(&self) -> bool
fn is_repeatable(&self) -> bool
Whether this action can be replayed by the dot-repeat command.
Sourceimpl From<DeleteBigWordEnd> for Action
impl From<DeleteBigWordEnd> for Action
Sourcefn from(v: DeleteBigWordEnd) -> Action
fn from(v: DeleteBigWordEnd) -> Action
Converts to this type from the input type.