pub struct DeleteWordForward(pub usize);Expand description
Deletes from cursor to the end of the current word (Emacs Alt+d).
Tuple Fields
0: usizeTrait Implementations
Sourceimpl Clone for DeleteWordForward
impl Clone for DeleteWordForward
Sourcefn clone(&self) -> DeleteWordForward
fn clone(&self) -> DeleteWordForward
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for DeleteWordForward
Sourceimpl Debug for DeleteWordForward
impl Debug for DeleteWordForward
Sourceimpl Execute for DeleteWordForward
impl Execute for DeleteWordForward
fn execute(&mut self, state: &mut EditorState)
Sourcefn is_repeatable(&self) -> bool
fn is_repeatable(&self) -> bool
Whether this action can be replayed by the dot-repeat command.
Sourceimpl From<DeleteWordForward> for Action
impl From<DeleteWordForward> for Action
Sourcefn from(v: DeleteWordForward) -> Action
fn from(v: DeleteWordForward) -> Action
Converts to this type from the input type.