pub struct ReplaceChar(pub char);Expand description
Replaces the character under the cursor with a given character. Intended to be called in normal mode.
Tuple Fields
0: charTrait Implementations
Sourceimpl Clone for ReplaceChar
impl Clone for ReplaceChar
Sourcefn clone(&self) -> ReplaceChar
fn clone(&self) -> ReplaceChar
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ReplaceChar
Sourceimpl Debug for ReplaceChar
impl Debug for ReplaceChar
Sourceimpl Execute for ReplaceChar
impl Execute for ReplaceChar
fn execute(&mut self, state: &mut EditorState)
Sourcefn is_repeatable(&self) -> bool
fn is_repeatable(&self) -> bool
Whether this action can be replayed by the dot-repeat command.
Sourceimpl From<ReplaceChar> for Action
impl From<ReplaceChar> for Action
Sourcefn from(v: ReplaceChar) -> Action
fn from(v: ReplaceChar) -> Action
Converts to this type from the input type.