FindForward

Struct FindForward 

pub struct FindForward(pub Option<char>);
Moves the cursor to the next occurrence of a character to the right on the current line (Vim f). Does nothing if the character is not found.

The target is None until the key handler supplies the next keystroke via Execute::char_arg.

Tuple Fields

0: Option<char>