KeyInput

Struct KeyInput 

pub struct KeyInput {
    pub key: KeyCode,
    pub modifiers: Modifiers,
}
A representation of a keyboard input.

Examples

Single key

use edtui::events::KeyInput;

let input = KeyInput::new('s');

Key with one modifier

use edtui::events::KeyInput;
use crossterm::event::KeyCode;

let input = KeyInput::ctrl(KeyCode::Esc);

Key with multiple modifiers

use edtui::events::KeyInput;
use crossterm::event::KeyModifiers;

let input = KeyInput::with_modifiers('k', KeyModifiers::CONTROL | KeyModifiers::SHIFT);

Fields

key: KeyCodemodifiers: Modifiers

Implementations

Source

impl KeyInput

pub fn new<K: Into<KeyCode>>(key: K) -> Self

Create a key input without any modifiers.

pub fn ctrl<K: Into<KeyCode>>(key: K) -> Self

Create a key input with the ctrl modifier.

pub fn alt<K: Into<KeyCode>>(key: K) -> Self

Create a key input with the alt modifier.

pub fn shift<K: Into<KeyCode>>(key: K) -> Self

Create a key input with the shift modifier.

pub fn with_modifiers<K: Into<KeyCode>, M: Into<Modifiers>>( key: K, modifiers: M, ) -> Self

Create a key input with a set of modifiers. Supports shift, ctrl and alt.

pub fn normalize_altgr(self) -> Self

Normalize AltGr key events for international keyboard support.

Strips Ctrl+Alt modifiers from non-alphabetic characters, allowing symbols like [, ], {, }, \, @ to be typed on keyboards where these require AltGr (e.g., German, Swiss German).