pub struct EditorStatusLine { /* private fields */ }Expand description
An optional status line for Editor.
Implementations
Sourceimpl EditorStatusLine
impl EditorStatusLine
Sourcepub fn style_text(self, style: Style) -> Self
👎Deprecated since 0.10.4: Please use style_mode and style_search instead
pub fn style_text(self, style: Style) -> Self
style_mode and style_search insteadOverwrite the style for the status lines content.
This method allows you to customize the appearance of the status lines content.
Sourcepub fn style_mode(self, style: impl Into<Option<Style>>) -> Self
pub fn style_mode(self, style: impl Into<Option<Style>>) -> Self
Overwrite the style for the status lines mode.
This method allows you to customize the appearance of the status lines mode.
Sourcepub fn style_search(self, style: impl Into<Option<Style>>) -> Self
pub fn style_search(self, style: impl Into<Option<Style>>) -> Self
Overwrite the style for the status lines search.
This method allows you to customize the appearance of the status lines search.
Sourcepub fn style_line(self, style: Style) -> Self
pub fn style_line(self, style: Style) -> Self
Overwrite the style for the status lines.
This method allows you to customize the appearance of the status line.
Sourcepub fn mode<S: Into<String>>(self, mode: S) -> Self
pub fn mode<S: Into<String>>(self, mode: S) -> Self
Overwrite the mode content for the status line.
This method is used internally to dynamically set the editors mode.
Sourcepub fn search<S: Into<String>>(self, search: Option<S>) -> Self
pub fn search<S: Into<String>>(self, search: Option<S>) -> Self
Overwrite the search content for the status line.
This method is used internally to dynamically set the editors mode.
pub fn align_left(self, align_left: bool) -> Self
alignment(HorizontalAlignment::Left) or alignment(HorizontalAlignment::Right) insteadSourcepub fn alignment(self, alignment: HorizontalAlignment) -> Self
pub fn alignment(self, alignment: HorizontalAlignment) -> Self
Set the alignment for the status line content.