pub struct FindForward(pub Option<char>);Expand description
Moves the cursor to the next occurrence of a character to the right on the
current line (Vim f). Does nothing if the character is not found.
The target is None until the key handler supplies the next keystroke via
Execute::char_arg.
Tuple Fields
0: Option<char>Trait Implementations
Sourceimpl Clone for FindForward
impl Clone for FindForward
Sourcefn clone(&self) -> FindForward
fn clone(&self) -> FindForward
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for FindForward
Sourceimpl Debug for FindForward
impl Debug for FindForward
Sourceimpl Execute for FindForward
impl Execute for FindForward
fn execute(&mut self, state: &mut EditorState)
Sourcefn char_arg(&mut self) -> Option<&mut Option<char>>
fn char_arg(&mut self) -> Option<&mut Option<char>>
Returns a handle to this action’s character argument if it takes one
(like
f/t). While the inner value is None, the action is still
waiting for the key handler to supply the next keystroke through it.Sourcefn is_repeatable(&self) -> bool
fn is_repeatable(&self) -> bool
Whether this action can be replayed by the dot-repeat command.
Sourceimpl From<FindForward> for Action
impl From<FindForward> for Action
Sourcefn from(v: FindForward) -> Action
fn from(v: FindForward) -> Action
Converts to this type from the input type.