pub struct EditorStatusLine { /* private fields */ }Expand description
An optional status line for Editor.
Implementations
Sourceimpl EditorStatusLine
impl EditorStatusLine
Sourcepub fn style_text(self, style: Style) -> Self
pub fn style_text(self, style: Style) -> Self
Overwrite the style for the status lines content.
This method allows you to customize the appearance of the status lines content.
Sourcepub fn style_line(self, style: Style) -> Self
pub fn style_line(self, style: Style) -> Self
Overwrite the style for the status lines.
This method allows you to customize the appearance of the status line.
Sourcepub fn mode<S: Into<String>>(self, mode: S) -> Self
pub fn mode<S: Into<String>>(self, mode: S) -> Self
Overwrite the mode content for the status line.
This method is used internally to dynamically set the editors mode.
Sourcepub fn search<S: Into<String>>(self, search: Option<S>) -> Self
pub fn search<S: Into<String>>(self, search: Option<S>) -> Self
Overwrite the search content for the status line.
This method is used internally to dynamically set the editors mode.
Sourcepub fn align_left(self, align_left: bool) -> Self
pub fn align_left(self, align_left: bool) -> Self
Set the alignment for the status line content.
Set to true to align content to the left, false to align to the right.