edtui

Struct EditorStatusLine

pub struct EditorStatusLine { /* private fields */ }
An optional status line for Editor.

Implementations

Source

impl EditorStatusLine

pub fn style_text(self, style: Style) -> Self

Overwrite the style for the status lines content.

This method allows you to customize the appearance of the status lines content.

Examples found in repository?
examples/app/theme.rs (line 29)
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
    pub fn new() -> Self {
        Self {
            editor: EditorTheme::default()
                .block(
                    Block::default()
                        .borders(Borders::ALL)
                        .border_type(BorderType::Thick)
                        .title("|Editor|")
                        .title_alignment(Alignment::Center),
                )
                .base(Style::default().bg(DARK_NIGHT).fg(WHITE))
                .cursor_style(Style::default().bg(WHITE).fg(DARK_NIGHT))
                .selection_style(Style::default().bg(ORANGE).fg(DARK_NIGHT))
                .status_line(
                    EditorStatusLine::default()
                        .style_text(Style::default().fg(DARK_NIGHT).bg(GREEN))
                        .style_line(Style::default().fg(WHITE).bg(DARK_GRAY))
                        .align_left(true),
                ),
        }
    }
More examples
Hide additional examples
examples/syntax_highlighting/theme.rs (line 29)
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
    pub fn new() -> Self {
        Self {
            editor: EditorTheme::default()
                .block(
                    Block::default()
                        .borders(Borders::ALL)
                        .border_type(BorderType::Thick)
                        .title("|Editor|")
                        .title_alignment(Alignment::Center),
                )
                .base(Style::default().bg(DARK_NIGHT).fg(WHITE))
                .cursor_style(Style::default().bg(WHITE).fg(DARK_NIGHT))
                .selection_style(Style::default().bg(ORANGE).fg(DARK_NIGHT))
                .status_line(
                    EditorStatusLine::default()
                        .style_text(Style::default().fg(DARK_NIGHT).bg(GREEN))
                        .style_line(Style::default().fg(WHITE).bg(DARK_GRAY))
                        .align_left(true),
                ),
        }
    }
examples/test_text/theme.rs (line 29)
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
    pub fn new() -> Self {
        Self {
            editor: EditorTheme::default()
                .block(
                    Block::default()
                        .borders(Borders::ALL)
                        .border_type(BorderType::Thick)
                        .title("|Editor|")
                        .title_alignment(Alignment::Center),
                )
                .base(Style::default().bg(DARK_NIGHT).fg(WHITE))
                .cursor_style(Style::default().bg(WHITE).fg(DARK_NIGHT))
                .selection_style(Style::default().bg(ORANGE).fg(DARK_NIGHT))
                .status_line(
                    EditorStatusLine::default()
                        .style_text(Style::default().fg(DARK_NIGHT).bg(GREEN))
                        .style_line(Style::default().fg(WHITE).bg(DARK_GRAY))
                        .align_left(true),
                ),
        }
    }
pub fn style_line(self, style: Style) -> Self

Overwrite the style for the status lines.

This method allows you to customize the appearance of the status line.

Examples found in repository?
examples/app/theme.rs (line 30)
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
    pub fn new() -> Self {
        Self {
            editor: EditorTheme::default()
                .block(
                    Block::default()
                        .borders(Borders::ALL)
                        .border_type(BorderType::Thick)
                        .title("|Editor|")
                        .title_alignment(Alignment::Center),
                )
                .base(Style::default().bg(DARK_NIGHT).fg(WHITE))
                .cursor_style(Style::default().bg(WHITE).fg(DARK_NIGHT))
                .selection_style(Style::default().bg(ORANGE).fg(DARK_NIGHT))
                .status_line(
                    EditorStatusLine::default()
                        .style_text(Style::default().fg(DARK_NIGHT).bg(GREEN))
                        .style_line(Style::default().fg(WHITE).bg(DARK_GRAY))
                        .align_left(true),
                ),
        }
    }
More examples
Hide additional examples
examples/syntax_highlighting/theme.rs (line 30)
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
    pub fn new() -> Self {
        Self {
            editor: EditorTheme::default()
                .block(
                    Block::default()
                        .borders(Borders::ALL)
                        .border_type(BorderType::Thick)
                        .title("|Editor|")
                        .title_alignment(Alignment::Center),
                )
                .base(Style::default().bg(DARK_NIGHT).fg(WHITE))
                .cursor_style(Style::default().bg(WHITE).fg(DARK_NIGHT))
                .selection_style(Style::default().bg(ORANGE).fg(DARK_NIGHT))
                .status_line(
                    EditorStatusLine::default()
                        .style_text(Style::default().fg(DARK_NIGHT).bg(GREEN))
                        .style_line(Style::default().fg(WHITE).bg(DARK_GRAY))
                        .align_left(true),
                ),
        }
    }
examples/test_text/theme.rs (line 30)
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
    pub fn new() -> Self {
        Self {
            editor: EditorTheme::default()
                .block(
                    Block::default()
                        .borders(Borders::ALL)
                        .border_type(BorderType::Thick)
                        .title("|Editor|")
                        .title_alignment(Alignment::Center),
                )
                .base(Style::default().bg(DARK_NIGHT).fg(WHITE))
                .cursor_style(Style::default().bg(WHITE).fg(DARK_NIGHT))
                .selection_style(Style::default().bg(ORANGE).fg(DARK_NIGHT))
                .status_line(
                    EditorStatusLine::default()
                        .style_text(Style::default().fg(DARK_NIGHT).bg(GREEN))
                        .style_line(Style::default().fg(WHITE).bg(DARK_GRAY))
                        .align_left(true),
                ),
        }
    }
pub fn mode<S: Into<String>>(self, mode: S) -> Self

Overwrite the mode content for the status line.

This method is used internally to dynamically set the editors mode.

pub fn search<S: Into<String>>(self, search: Option<S>) -> Self

Overwrite the search content for the status line.

This method is used internally to dynamically set the editors mode.

pub fn align_left(self, align_left: bool) -> Self

Set the alignment for the status line content.

Set to true to align content to the left, false to align to the right.

Examples found in repository?
examples/app/theme.rs (line 31)
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
    pub fn new() -> Self {
        Self {
            editor: EditorTheme::default()
                .block(
                    Block::default()
                        .borders(Borders::ALL)
                        .border_type(BorderType::Thick)
                        .title("|Editor|")
                        .title_alignment(Alignment::Center),
                )
                .base(Style::default().bg(DARK_NIGHT).fg(WHITE))
                .cursor_style(Style::default().bg(WHITE).fg(DARK_NIGHT))
                .selection_style(Style::default().bg(ORANGE).fg(DARK_NIGHT))
                .status_line(
                    EditorStatusLine::default()
                        .style_text(Style::default().fg(DARK_NIGHT).bg(GREEN))
                        .style_line(Style::default().fg(WHITE).bg(DARK_GRAY))
                        .align_left(true),
                ),
        }
    }
More examples
Hide additional examples
examples/syntax_highlighting/theme.rs (line 31)
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
    pub fn new() -> Self {
        Self {
            editor: EditorTheme::default()
                .block(
                    Block::default()
                        .borders(Borders::ALL)
                        .border_type(BorderType::Thick)
                        .title("|Editor|")
                        .title_alignment(Alignment::Center),
                )
                .base(Style::default().bg(DARK_NIGHT).fg(WHITE))
                .cursor_style(Style::default().bg(WHITE).fg(DARK_NIGHT))
                .selection_style(Style::default().bg(ORANGE).fg(DARK_NIGHT))
                .status_line(
                    EditorStatusLine::default()
                        .style_text(Style::default().fg(DARK_NIGHT).bg(GREEN))
                        .style_line(Style::default().fg(WHITE).bg(DARK_GRAY))
                        .align_left(true),
                ),
        }
    }
examples/test_text/theme.rs (line 31)
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
    pub fn new() -> Self {
        Self {
            editor: EditorTheme::default()
                .block(
                    Block::default()
                        .borders(Borders::ALL)
                        .border_type(BorderType::Thick)
                        .title("|Editor|")
                        .title_alignment(Alignment::Center),
                )
                .base(Style::default().bg(DARK_NIGHT).fg(WHITE))
                .cursor_style(Style::default().bg(WHITE).fg(DARK_NIGHT))
                .selection_style(Style::default().bg(ORANGE).fg(DARK_NIGHT))
                .status_line(
                    EditorStatusLine::default()
                        .style_text(Style::default().fg(DARK_NIGHT).bg(GREEN))
                        .style_line(Style::default().fg(WHITE).bg(DARK_GRAY))
                        .align_left(true),
                ),
        }
    }