edtui

Struct EditorTheme

pub struct EditorTheme<'a> {
    pub base: Style,
    pub cursor_style: Style,
    pub selection_style: Style,
    pub block: Option<Block<'a>>,
    pub status_line: Option<EditorStatusLine>,
}
The theme data of the Editor.

Fields

base: Style

The base text style

cursor_style: Style

The cursor style

selection_style: Style

The text style in visual mode when a text is selected

block: Option<Block<'a>>

The surrounding block

status_line: Option<EditorStatusLine>

An optional [StatusLine] displaying the editor mode

Implementations

Source

impl<'a> EditorTheme<'a>

pub fn base(self, base: Style) -> Self

This method allows you to customize the base appearance of the Editor.

Examples found in repository?
examples/app/theme.rs (line 24)
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
    pub fn new() -> Self {
        Self {
            editor: EditorTheme::default()
                .block(
                    Block::default()
                        .borders(Borders::ALL)
                        .border_type(BorderType::Thick)
                        .title("|Editor|")
                        .title_alignment(Alignment::Center),
                )
                .base(Style::default().bg(DARK_NIGHT).fg(WHITE))
                .cursor_style(Style::default().bg(WHITE).fg(DARK_NIGHT))
                .selection_style(Style::default().bg(ORANGE).fg(DARK_NIGHT))
                .status_line(
                    EditorStatusLine::default()
                        .style_text(Style::default().fg(DARK_NIGHT).bg(GREEN))
                        .style_line(Style::default().fg(WHITE).bg(DARK_GRAY))
                        .align_left(true),
                ),
        }
    }
More examples
Hide additional examples
examples/syntax_highlighting/theme.rs (line 24)
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
    pub fn new() -> Self {
        Self {
            editor: EditorTheme::default()
                .block(
                    Block::default()
                        .borders(Borders::ALL)
                        .border_type(BorderType::Thick)
                        .title("|Editor|")
                        .title_alignment(Alignment::Center),
                )
                .base(Style::default().bg(DARK_NIGHT).fg(WHITE))
                .cursor_style(Style::default().bg(WHITE).fg(DARK_NIGHT))
                .selection_style(Style::default().bg(ORANGE).fg(DARK_NIGHT))
                .status_line(
                    EditorStatusLine::default()
                        .style_text(Style::default().fg(DARK_NIGHT).bg(GREEN))
                        .style_line(Style::default().fg(WHITE).bg(DARK_GRAY))
                        .align_left(true),
                ),
        }
    }
examples/test_text/theme.rs (line 24)
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
    pub fn new() -> Self {
        Self {
            editor: EditorTheme::default()
                .block(
                    Block::default()
                        .borders(Borders::ALL)
                        .border_type(BorderType::Thick)
                        .title("|Editor|")
                        .title_alignment(Alignment::Center),
                )
                .base(Style::default().bg(DARK_NIGHT).fg(WHITE))
                .cursor_style(Style::default().bg(WHITE).fg(DARK_NIGHT))
                .selection_style(Style::default().bg(ORANGE).fg(DARK_NIGHT))
                .status_line(
                    EditorStatusLine::default()
                        .style_text(Style::default().fg(DARK_NIGHT).bg(GREEN))
                        .style_line(Style::default().fg(WHITE).bg(DARK_GRAY))
                        .align_left(true),
                ),
        }
    }
pub fn base_style(&self) -> Style

Returns the base style.

pub fn block(self, block: Block<'a>) -> Self

This method allows you to customize the block surrrounding the Editor.

Examples found in repository?
examples/app/theme.rs (lines 17-23)
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
    pub fn new() -> Self {
        Self {
            editor: EditorTheme::default()
                .block(
                    Block::default()
                        .borders(Borders::ALL)
                        .border_type(BorderType::Thick)
                        .title("|Editor|")
                        .title_alignment(Alignment::Center),
                )
                .base(Style::default().bg(DARK_NIGHT).fg(WHITE))
                .cursor_style(Style::default().bg(WHITE).fg(DARK_NIGHT))
                .selection_style(Style::default().bg(ORANGE).fg(DARK_NIGHT))
                .status_line(
                    EditorStatusLine::default()
                        .style_text(Style::default().fg(DARK_NIGHT).bg(GREEN))
                        .style_line(Style::default().fg(WHITE).bg(DARK_GRAY))
                        .align_left(true),
                ),
        }
    }
More examples
Hide additional examples
examples/syntax_highlighting/theme.rs (lines 17-23)
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
    pub fn new() -> Self {
        Self {
            editor: EditorTheme::default()
                .block(
                    Block::default()
                        .borders(Borders::ALL)
                        .border_type(BorderType::Thick)
                        .title("|Editor|")
                        .title_alignment(Alignment::Center),
                )
                .base(Style::default().bg(DARK_NIGHT).fg(WHITE))
                .cursor_style(Style::default().bg(WHITE).fg(DARK_NIGHT))
                .selection_style(Style::default().bg(ORANGE).fg(DARK_NIGHT))
                .status_line(
                    EditorStatusLine::default()
                        .style_text(Style::default().fg(DARK_NIGHT).bg(GREEN))
                        .style_line(Style::default().fg(WHITE).bg(DARK_GRAY))
                        .align_left(true),
                ),
        }
    }
examples/test_text/theme.rs (lines 17-23)
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
    pub fn new() -> Self {
        Self {
            editor: EditorTheme::default()
                .block(
                    Block::default()
                        .borders(Borders::ALL)
                        .border_type(BorderType::Thick)
                        .title("|Editor|")
                        .title_alignment(Alignment::Center),
                )
                .base(Style::default().bg(DARK_NIGHT).fg(WHITE))
                .cursor_style(Style::default().bg(WHITE).fg(DARK_NIGHT))
                .selection_style(Style::default().bg(ORANGE).fg(DARK_NIGHT))
                .status_line(
                    EditorStatusLine::default()
                        .style_text(Style::default().fg(DARK_NIGHT).bg(GREEN))
                        .style_line(Style::default().fg(WHITE).bg(DARK_GRAY))
                        .align_left(true),
                ),
        }
    }
pub fn cursor_style(self, style: Style) -> Self

This method allows you to customize the style of the cursor of the Editor.

Examples found in repository?
examples/app/theme.rs (line 25)
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
    pub fn new() -> Self {
        Self {
            editor: EditorTheme::default()
                .block(
                    Block::default()
                        .borders(Borders::ALL)
                        .border_type(BorderType::Thick)
                        .title("|Editor|")
                        .title_alignment(Alignment::Center),
                )
                .base(Style::default().bg(DARK_NIGHT).fg(WHITE))
                .cursor_style(Style::default().bg(WHITE).fg(DARK_NIGHT))
                .selection_style(Style::default().bg(ORANGE).fg(DARK_NIGHT))
                .status_line(
                    EditorStatusLine::default()
                        .style_text(Style::default().fg(DARK_NIGHT).bg(GREEN))
                        .style_line(Style::default().fg(WHITE).bg(DARK_GRAY))
                        .align_left(true),
                ),
        }
    }
More examples
Hide additional examples
examples/syntax_highlighting/theme.rs (line 25)
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
    pub fn new() -> Self {
        Self {
            editor: EditorTheme::default()
                .block(
                    Block::default()
                        .borders(Borders::ALL)
                        .border_type(BorderType::Thick)
                        .title("|Editor|")
                        .title_alignment(Alignment::Center),
                )
                .base(Style::default().bg(DARK_NIGHT).fg(WHITE))
                .cursor_style(Style::default().bg(WHITE).fg(DARK_NIGHT))
                .selection_style(Style::default().bg(ORANGE).fg(DARK_NIGHT))
                .status_line(
                    EditorStatusLine::default()
                        .style_text(Style::default().fg(DARK_NIGHT).bg(GREEN))
                        .style_line(Style::default().fg(WHITE).bg(DARK_GRAY))
                        .align_left(true),
                ),
        }
    }
examples/test_text/theme.rs (line 25)
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
    pub fn new() -> Self {
        Self {
            editor: EditorTheme::default()
                .block(
                    Block::default()
                        .borders(Borders::ALL)
                        .border_type(BorderType::Thick)
                        .title("|Editor|")
                        .title_alignment(Alignment::Center),
                )
                .base(Style::default().bg(DARK_NIGHT).fg(WHITE))
                .cursor_style(Style::default().bg(WHITE).fg(DARK_NIGHT))
                .selection_style(Style::default().bg(ORANGE).fg(DARK_NIGHT))
                .status_line(
                    EditorStatusLine::default()
                        .style_text(Style::default().fg(DARK_NIGHT).bg(GREEN))
                        .style_line(Style::default().fg(WHITE).bg(DARK_GRAY))
                        .align_left(true),
                ),
        }
    }
pub fn hide_cursor(self) -> Self

Hides the cursors.

pub fn selection_style(self, style: Style) -> Self

This method allows you to customize the style of the selection of the Editor in visual mode.

Examples found in repository?
examples/app/theme.rs (line 26)
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
    pub fn new() -> Self {
        Self {
            editor: EditorTheme::default()
                .block(
                    Block::default()
                        .borders(Borders::ALL)
                        .border_type(BorderType::Thick)
                        .title("|Editor|")
                        .title_alignment(Alignment::Center),
                )
                .base(Style::default().bg(DARK_NIGHT).fg(WHITE))
                .cursor_style(Style::default().bg(WHITE).fg(DARK_NIGHT))
                .selection_style(Style::default().bg(ORANGE).fg(DARK_NIGHT))
                .status_line(
                    EditorStatusLine::default()
                        .style_text(Style::default().fg(DARK_NIGHT).bg(GREEN))
                        .style_line(Style::default().fg(WHITE).bg(DARK_GRAY))
                        .align_left(true),
                ),
        }
    }
More examples
Hide additional examples
examples/syntax_highlighting/theme.rs (line 26)
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
    pub fn new() -> Self {
        Self {
            editor: EditorTheme::default()
                .block(
                    Block::default()
                        .borders(Borders::ALL)
                        .border_type(BorderType::Thick)
                        .title("|Editor|")
                        .title_alignment(Alignment::Center),
                )
                .base(Style::default().bg(DARK_NIGHT).fg(WHITE))
                .cursor_style(Style::default().bg(WHITE).fg(DARK_NIGHT))
                .selection_style(Style::default().bg(ORANGE).fg(DARK_NIGHT))
                .status_line(
                    EditorStatusLine::default()
                        .style_text(Style::default().fg(DARK_NIGHT).bg(GREEN))
                        .style_line(Style::default().fg(WHITE).bg(DARK_GRAY))
                        .align_left(true),
                ),
        }
    }
examples/test_text/theme.rs (line 26)
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
    pub fn new() -> Self {
        Self {
            editor: EditorTheme::default()
                .block(
                    Block::default()
                        .borders(Borders::ALL)
                        .border_type(BorderType::Thick)
                        .title("|Editor|")
                        .title_alignment(Alignment::Center),
                )
                .base(Style::default().bg(DARK_NIGHT).fg(WHITE))
                .cursor_style(Style::default().bg(WHITE).fg(DARK_NIGHT))
                .selection_style(Style::default().bg(ORANGE).fg(DARK_NIGHT))
                .status_line(
                    EditorStatusLine::default()
                        .style_text(Style::default().fg(DARK_NIGHT).bg(GREEN))
                        .style_line(Style::default().fg(WHITE).bg(DARK_GRAY))
                        .align_left(true),
                ),
        }
    }
pub fn status_line(self, status_line: EditorStatusLine) -> Self

This method allows you to customize the style of the [StatusLine] of the Editor. See [StatusLine] on how to modify its appearance. Use hide_status_line to hide the status line.

Examples found in repository?
examples/app/theme.rs (lines 27-32)
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
    pub fn new() -> Self {
        Self {
            editor: EditorTheme::default()
                .block(
                    Block::default()
                        .borders(Borders::ALL)
                        .border_type(BorderType::Thick)
                        .title("|Editor|")
                        .title_alignment(Alignment::Center),
                )
                .base(Style::default().bg(DARK_NIGHT).fg(WHITE))
                .cursor_style(Style::default().bg(WHITE).fg(DARK_NIGHT))
                .selection_style(Style::default().bg(ORANGE).fg(DARK_NIGHT))
                .status_line(
                    EditorStatusLine::default()
                        .style_text(Style::default().fg(DARK_NIGHT).bg(GREEN))
                        .style_line(Style::default().fg(WHITE).bg(DARK_GRAY))
                        .align_left(true),
                ),
        }
    }
More examples
Hide additional examples
examples/syntax_highlighting/theme.rs (lines 27-32)
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
    pub fn new() -> Self {
        Self {
            editor: EditorTheme::default()
                .block(
                    Block::default()
                        .borders(Borders::ALL)
                        .border_type(BorderType::Thick)
                        .title("|Editor|")
                        .title_alignment(Alignment::Center),
                )
                .base(Style::default().bg(DARK_NIGHT).fg(WHITE))
                .cursor_style(Style::default().bg(WHITE).fg(DARK_NIGHT))
                .selection_style(Style::default().bg(ORANGE).fg(DARK_NIGHT))
                .status_line(
                    EditorStatusLine::default()
                        .style_text(Style::default().fg(DARK_NIGHT).bg(GREEN))
                        .style_line(Style::default().fg(WHITE).bg(DARK_GRAY))
                        .align_left(true),
                ),
        }
    }
examples/test_text/theme.rs (lines 27-32)
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
    pub fn new() -> Self {
        Self {
            editor: EditorTheme::default()
                .block(
                    Block::default()
                        .borders(Borders::ALL)
                        .border_type(BorderType::Thick)
                        .title("|Editor|")
                        .title_alignment(Alignment::Center),
                )
                .base(Style::default().bg(DARK_NIGHT).fg(WHITE))
                .cursor_style(Style::default().bg(WHITE).fg(DARK_NIGHT))
                .selection_style(Style::default().bg(ORANGE).fg(DARK_NIGHT))
                .status_line(
                    EditorStatusLine::default()
                        .style_text(Style::default().fg(DARK_NIGHT).bg(GREEN))
                        .style_line(Style::default().fg(WHITE).bg(DARK_GRAY))
                        .align_left(true),
                ),
        }
    }
pub fn hide_status_line(self) -> Self

Hides the status lilne.